/*
 * $Revision: 1.6.2.4 $
 */


/*
**  If you make local modifications to INN, change this line as needed:
*/
#define LOCAL_STRING	""


/*
**  Try to avoid changing these.
*/
#define RELEASE "2"
#define PATCHLEVEL "2.1"
#define DATE "25-Aug-1999"
#define RELEASE_C 2
#define PATCHLEVEL_C 2
#define SUB_PATCHLEVEL_C 1


/*
**  See lib/innvers.c, but the version string should look like this:
**	INN ${RELEASE}.${PATCHLEVEL} ${DATE} (${LOCAL_STRING})
**  for example:
**	INN 1.0 10-Feb-92 (FOO.COM)
*/
